/**
 * Created by Richard Farrell on 22/04/2017.
 */

Game.preload = function(game) {

    this.preloadText = null;
    this.playButton = null;
    this.fullscreenButton = null;
};

Game.preload.prototype = {

    preload: function() {

        this.stage.backgroundColor = '#000000';

        this.preloadText = this.add.bitmapText(
            this.world.centerX,
            this.world.centerY,
            'font0',
            'PLAY',
            12
        );

        this.preloadText.anchor.set(0.5);
        this.preloadText.tint = 0xebeb7f;

        this.playButton = this.add.button(
            this.world.centerX,
            this.world.centerY,
            'play-button',
            function() {
                this.state.start('play');
                if(!Phaser.Device.desktop) {
                    toggleFullscreen();
                }
            },
            this,
            2, 0, 1, 0
        );

        // optional fullscreen button - implement here for desktop only (might want to change line 37 if changing this)
        if(Phaser.Device.desktop) {
            this.addFullscreenButton();
        }

        this.playButton.anchor.set(0.5);
        this.playButton.visible = false;
        this.playButton.inputEnabled = false;
//        this.playButton.onInputOver.add(function(){}, this);
//        this.playButton.onInputOut.add(function(){}, this);
//        this.playButton.onInputUp.add(function(){}, this);

        this.load.onLoadStart.add(function() {
            this.preloadText.setText("0%");
        }, this);

        this.load.onFileComplete.add(function(progress, cacheKey, success, totalLoaded, totalFiles) {
            this.preloadText.setText(progress + "%");
        }, this);

        this.load.onLoadComplete.add(function() {
            this.preloadText.visible = false;
            this.playButton.inputEnabled = true;
            this.playButton.visible = true;
        }, this);

        this.loadContent();
    },

    addFullscreenButton: function() {

        this.fullscreenButton = this.add.button(
            this.world.width - 10,
            this.world.height - 10,
            'fullscreen-button',
            function() {
                toggleFullscreen();
            },
            this,
            2, 0, 1, 0
        );

        this.fullscreenButton.visible = true;
        this.fullscreenButton.inputEnabled = true;
    },

    loadContent: function() {

        // horse
        this.load.spritesheet('horse0', 'assets/images/horse0-32x32.png', 32, 32);
        this.load.spritesheet('horse1', 'assets/images/horse1-32x32.png', 32, 32);
        this.load.spritesheet('jockey', 'assets/images/jockey-16x16.png', 16, 16);
        this.load.spritesheet('jockey0', 'assets/images/jockey0-16x16.png', 16, 16);
        this.load.image('saddle', 'assets/images/saddle-8x8.png');

        // background
        this.load.spritesheet('tileset', 'assets/images/tiles-16x16.png', 16, 16);
        this.load.image('finish', 'assets/images/finish-16x32.png');
        this.load.image('bar', 'assets/images/bar-16x16.png');

        // cards
        this.load.spritesheet('card', 'assets/images/cards-32x52.png', 32, 52);

        // menus and buttons
        this.load.spritesheet('button', 'assets/images/button-32x32.png', 32, 32);
        this.load.image('font1', 'assets/fonts/font-5by9.png');

        this.load.audio('gallop', 'assets/sounds/gallop.wav');
        this.load.audio('gallop-fadeOut', 'assets/sounds/gallop-fadeOut.wav');
    },

    create: function() {
        this.playButton.inputEnabled = true;
    }
};